From inside a project directory, for a project that has a repository on Github, call this function to create a pkgdown site hosted on Github Pages, and automatically deployed using Github Actions.
Arguments
- whoami
The result of gh::gh_whoami
- open
Should a web browser be opened to the new pkgdown site? Default is
FALSE.
Details
This function uses the user-provided response from gh::gh_whoami() to identify the Github
repo. It will also update the URL in the DESCRIPTION to include the pkgdown site URL.